@@ -1,3 +1,5 @@
+from typing import List, Optional, Tuple
+
 import numpy as np
 
 
@@ -20,13 +22,35 @@ def estimate_order_of_convergence(abscissae, errors):
 
 
 class EOCRecorder:
+    """
+    .. automethod:: add_data_point
+
+    .. automethod:: estimate_order_of_convergence
+    .. automethod:: order_estimate
+    .. automethod:: max_error
+
+    .. automethod:: pretty_print
+    .. automethod:: write_gnuplot_file
+    """
+
     def __init__(self):
-        self.history = []
+        self.history: List[Tuple[float, float]] = []
+
+    def add_data_point(self, abscissa: float, error: float) -> None:
+        if not (np.isscalar(abscissa)
+                or (isinstance(abscissa, np.ndarray) and abscissa.shape == ())):
+            raise TypeError(
+                    f"'abscissa' is not a scalar: '{type(abscissa).__name__}'")
+
+        if not (np.isscalar(error)
+                or (isinstance(error, np.ndarray) and error.shape == ())):
+            raise TypeError(f"'error' is not a scalar: '{type(error).__name__}'")
 
-    def add_data_point(self, abscissa, error):
         self.history.append((abscissa, error))
 
-    def estimate_order_of_convergence(self, gliding_mean=None):
+    def estimate_order_of_convergence(self,
+            gliding_mean: Optional[int] = None,
+            ) -> np.ndarray:
         abscissae = np.array([a for a, e in self.history])
         errors = np.array([e for a, e in self.history])
 
@@ -46,13 +70,13 @@ class EOCRecorder:
                 abscissae[i:i+gliding_mean], errors[i:i+gliding_mean])
         return result
 
-    def order_estimate(self):
+    def order_estimate(self) -> float:
         return self.estimate_order_of_convergence()[0, 1]
 
-    def max_error(self):
+    def max_error(self) -> float:
         return max(err for absc, err in self.history)
 
-    def pretty_print(self,
+    def _to_table(self, *,
             abscissa_label="h",
             error_label="Error",
             gliding_mean=2,
@@ -75,16 +99,44 @@ class EOCRecorder:
 
             tbl.add_row((absc_str, err_str, eoc_str))
 
+        return tbl
+
+    def pretty_print(self, *,
+            abscissa_label: str = "h",
+            error_label: str = "Error",
+            gliding_mean: int = 2,
+            abscissa_format: str = "%s",
+            error_format: str = "%s",
+            eoc_format: str = "%s",
+            table_type: str = "markdown") -> str:
+        tbl = self._to_table(
+                abscissa_label=abscissa_label, error_label=error_label,
+                abscissa_format=abscissa_format,
+                error_format=error_format,
+                eoc_format=eoc_format,
+                gliding_mean=gliding_mean)
+
+        if table_type == "markdown":
+            tbl_str = tbl.github_markdown()
+        elif table_type == "latex":
+            tbl_str = tbl.latex()
+        elif table_type == "ascii":
+            tbl_str = str(tbl)
+        elif table_type == "csv":
+            tbl_str = tbl.csv()
+        else:
+            raise ValueError(f"unknown table type: {table_type}")
+
         if len(self.history) > 1:
-            return "{}\n\nOverall EOC: {}".format(str(tbl),
+            return "{}\n\nOverall EOC: {}".format(tbl_str,
                     self.estimate_order_of_convergence()[0, 1])
         else:
-            return str(tbl)
+            return tbl_str
 
     def __str__(self):
         return self.pretty_print()
 
-    def write_gnuplot_file(self, filename):
+    def write_gnuplot_file(self, filename: str) -> None:
         outfile = open(filename, "w")
         for absc, err in self.history:
             outfile.write(f"{absc:f} {err:f}\n")
@@ -92,8 +144,8 @@ class EOCRecorder:
         const = result[0, 0]
         order = result[0, 1]
         outfile.write("\n")
-        for absc, err in self.history:
-            outfile.write("{:f} {:f}\n".format(absc, const * absc**(-order)))
+        for absc, _err in self.history:
+            outfile.write(f"{absc:f} {const * absc**(-order):f}\n")
 
 # }}}
 
