@@ -22,11 +22,18 @@ Internal stuff that is only here because the documentation tool wants it
 .. class:: T_co
 
     A covariant type variable used in, e.g. :meth:`Taggable.copy`.
+
+
+.. class:: TagsOfTypeT
+
+    A type variable used in :meth:`Taggable.tags_of_type`.
 """
 
 from dataclasses import dataclass
-from typing import Tuple, Set, Any, FrozenSet, Union, Iterable, TypeVar
-from pytools import memoize
+from typing import (Tuple, Set, Any, FrozenSet, Union, Iterable,  # noqa: F401
+                    TypeVar, Type)
+from pytools import memoize, memoize_method
+from abc import ABC, abstractmethod
 
 __copyright__ = """
 Copyright (C) 2020 Andreas Klöckner
@@ -160,6 +167,7 @@ class UniqueTag(Tag):
 TagsType = FrozenSet[Tag]
 TagOrIterableType = Union[Iterable[Tag], Tag, None]
 T_co = TypeVar("T_co", bound="Taggable")
+TagsOfTypeT = TypeVar("TagsOfTypeT", bound="Type[Tag]")
 
 
 # {{{ UniqueTag rules checking
@@ -222,7 +230,7 @@ def normalize_tags(tags: TagOrIterableType) -> TagsType:
 
 # {{{ taggable
 
-class Taggable:
+class Taggable(ABC):
     """
     Parent class for objects with a `tags` attribute.
 
@@ -235,6 +243,7 @@ class Taggable:
     .. automethod:: copy
     .. automethod:: tagged
     .. automethod:: without_tags
+    .. automethod:: tags_of_type
 
     .. versionadded:: 2021.1
     """
@@ -255,12 +264,12 @@ class Taggable:
         """
         self.tags = tags
 
+    @abstractmethod
     def copy(self: T_co, **kwargs: Any) -> T_co:
         """
         Returns of copy of *self* with the specified tags. This method
         should be overridden by subclasses.
         """
-        raise NotImplementedError("The copy function is not implemented.")
 
     def tagged(self: T_co, tags: TagOrIterableType) -> T_co:
         """
@@ -295,6 +304,17 @@ class Taggable:
 
         return self.copy(tags=check_tag_uniqueness(new_tags))
 
+    @memoize_method
+    def tags_of_type(self, tag_t: TagsOfTypeT) -> FrozenSet[TagsOfTypeT]:
+        """
+        Returns *self*'s tags of type *tag_t*.
+        """
+        # type-ignore reason: mypy can't tell the generator has elements of
+        # type 'TagsOfTypeT' (infers it as elements of type 'Tag')
+        return frozenset(tag  # type: ignore[misc]
+                         for tag in self.tags
+                         if isinstance(tag, tag_t))
+
 # }}}
 
 # vim: foldmethod=marker
